# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cli_cqu', 'cli_cqu.data', 'cli_cqu.util']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.8.2,<5.0.0',
 'icalendar>=4.0.4,<5.0.0',
 'lxml>=4.5.0,<5.0.0',
 'pydantic>=1.4,<2.0',
 'requests>=2.22.0,<3.0.0',
 'toml>=0.10.1,<0.11.0']

entry_points = \
{'console_scripts': ['cli-cqu = cli_cqu:cli_main']}

setup_kwargs = {
    'name': 'cli-cqu',
    'version': '0.5.0',
    'description': 'CLI CQU 是重庆大学 jxgl 网站的命令行界面。',
    'long_description': '重庆大学（CQU）的命令行客户端\n\n提供以下功能：\n\n- 下载课表\n    -   保存为 JSON，便于后续处理（字段定义参考 ``cli_cqu.model`` 模块）\n    -   保存为 ICalendar 日历日程，可导入 Outlook 等日历应用\n- 查询成绩\n    -   通过老教务网的接口获取成绩单\n\n使用\n====\n\n在命令行运行可执行程序 ``cli-cqu`` 即可进入 CLI CQU 的交互式 Shell 中，可以采用类似于命令行的操作方式。\n进入 REPL 后，提示符被替换为 ``cli cqu>`` 。\n\n第一次运行时，需要输入用户名与密码，分别需要教学管理（jxgl）和老教务网（oldjw）的两个帐号，两个帐号的密码不一定相同，一般来说，老教务网的密码会是初始密码（身份证后 6 位）。\n账户信息会保存到本地（ ``~/.config/cli-cqu/account.toml`` ），之后使用时会直接从文件读取，而无需手动输入。如果有更改，需自行修改文件内容。\n\n1. 退出程序::\n\n    exit\n\n2. 查询帮助::\n\n    help [command_name]\n\n当无参数时，此命令会显示程序整体的帮助信息；当后缀一个命令名时，将显示对应命令的帮助信息。\n\n3. 下载课程表（JSON 格式）::\n\n    courses-json filename\n\n将 **当前学期** 的课程表内容下载为 JSON 文件至 filename 所指定的路径。\n\n4. 下载课程表（Ical 格式）::\n\n    courses-ical filename startdate\n\n将 **当前学期** 的课程表内容下载为 ICalendar 日志格式至 filename 所指定的路径。\n\n5. 下载全部成绩（JSON 格式）::\n\n    assignments-json filename\n\n将 **所有学期的全部科目** 的成绩以 JSON 的格式下载至 filename 指定的路径。\n\n安装\n====\n\n你可以使用 pip 安装，由于使用了 f-string，需要 python 3.6 以上::\n\n    pip install cli-cqu\n\n或者使用 pipx ::\n\n    pipx install cli-cqu\n\n贡献\n====\n\n此项目基于 MIT 协议发行，你可以在遵守协议的情况下做任何事。\n\n下面是本项目各模块的介绍\n\n- ``cli_cqu`` App 对象和命令行接口\n    - ``cli_cqu.login`` 模块是登录功能\n    - ``cli_cqu.data`` 模块是需要用到的数据，例如常量、路由、解析规则（函数）等。\n        - ``cli_cqu.data.ua`` User-Agent。\n        - ``cli_cqu.data.js_equality`` 与 jxgl 网页前端的 js 等效的一些函数。\n        - ``cli_cqu.data.route`` 路由，根据 jxgl 的功能模块分类\n        - ``cli_cqu.data.schedule`` 日程表\n    - ``cli_cqu.model`` 数据模型\n    - ``cli_cqu.util`` 其他辅助功能\n',
    'author': 'zombie110year',
    'author_email': 'zombie110year@outlook.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/zombie110year/cli_cqu',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
